@@ -22,6 +22,7 @@
 #include "htmlexport.h"
 #include "htmlexportsettings.h"
 #include "stringify.h"
+#include "incidenceformatter.h"
 
 #include <kcalcore/memorycalendar.h>
 using namespace KCalCore;
@@ -30,9 +31,9 @@ using namespace KCalCore;
 
 #include <KLocalizedString>
 
-#include <QtCore/QFile>
-#include <QtCore/QMap>
-#include <QtCore/QTextStream>
+#include <QFile>
+#include <QMap>
+#include <QTextStream>
 #include <QApplication>
 #include <QLocale>
 
@@ -45,11 +46,13 @@ class KCalUtils::HtmlExportPrivate
 {
 public:
     HtmlExportPrivate(MemoryCalendar *calendar, HTMLExportSettings *settings)
-        : mCalendar(calendar), mSettings(settings)
-    {}
+        : mCalendar(calendar)
+        , mSettings(settings)
+    {
+    }
 
-    MemoryCalendar *mCalendar;
-    HTMLExportSettings *mSettings;
+    MemoryCalendar *mCalendar = nullptr;
+    HTMLExportSettings *mSettings = nullptr;
     QMap<QDate, QString> mHolidayMap;
 };
 //@endcond
@@ -161,7 +164,7 @@ bool HtmlExport::save(QTextStream *ts)
 void HtmlExport::createMonthView(QTextStream *ts)
 {
     QDate start = fromDate();
-    start.setYMD(start.year(), start.month(), 1);    // go back to first day in month
+    start.setDate(start.year(), start.month(), 1);    // go back to first day in month
 
     QDate end(start.year(), start.month(), start.daysInMonth());
 
@@ -214,13 +217,14 @@ void HtmlExport::createMonthView(QTextStream *ts)
 
                 // Only print events within the from-to range
                 if (start >= fromDate() && start <= toDate()) {
-                    Event::List events = d->mCalendar->events(start, d->mCalendar->timeSpec(),
-                                         EventSortStartDate,
-                                         SortDirectionAscending);
+                    Event::List events = d->mCalendar->events(start, d->mCalendar->timeZone(),
+                                                              EventSortStartDate,
+                                                              SortDirectionAscending);
                     if (events.count()) {
                         *ts << "<table>";
                         Event::List::ConstIterator it;
-                        for (it = events.constBegin(); it != events.constEnd(); ++it) {
+                        Event::List::ConstIterator end(events.constEnd());
+                        for (it = events.constBegin(); it != end; ++it) {
                             if (checkSecrecy(*it)) {
                                 createEvent(ts, *it, start, false);
                             }
@@ -242,8 +246,8 @@ void HtmlExport::createMonthView(QTextStream *ts)
             startyear += 1;
             startmonth = 1;
         }
-        start.setYMD(startyear, startmonth, 1);
-        end.setYMD(start.year(), start.month(), start.daysInMonth());
+        start.setDate(startyear, startmonth, 1);
+        end.setDate(start.year(), start.month(), start.daysInMonth());
     }
 }
 
@@ -253,7 +257,7 @@ void HtmlExport::createEventList(QTextStream *ts)
     *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">" << endl;
     *ts << "  <tr>" << endl;
     *ts << "    <th class=\"sum\">" << i18nc("@title:column event start time",
-            "Start Time") << "</th>" << endl;
+                                             "Start Time") << "</th>" << endl;
     *ts << "    <th>" << i18nc("@title:column event end time",
                                "End Time") << "</th>" << endl;
     *ts << "    <th>" << i18nc("@title:column event description",
@@ -278,9 +282,9 @@ void HtmlExport::createEventList(QTextStream *ts)
 
     for (QDate dt = fromDate(); dt <= toDate(); dt = dt.addDays(1)) {
         qCDebug(KCALUTILS_LOG) << "Getting events for" << dt.toString();
-        Event::List events = d->mCalendar->events(dt, d->mCalendar->timeSpec(),
-                             EventSortStartDate,
-                             SortDirectionAscending);
+        Event::List events = d->mCalendar->events(dt, d->mCalendar->timeZone(),
+                                                  EventSortStartDate,
+                                                  SortDirectionAscending);
         if (events.count()) {
             *ts << "  <tr><td colspan=\"" << QString::number(columns)
                 << "\" class=\"datehead\"><i>"
@@ -288,7 +292,8 @@ void HtmlExport::createEventList(QTextStream *ts)
                 << "</i></td></tr>" << endl;
 
             Event::List::ConstIterator it;
-            for (it = events.constBegin(); it != events.constEnd(); ++it) {
+            const Event::List::ConstIterator end(events.constEnd());
+            for (it = events.constBegin(); it != end; ++it) {
                 if (checkSecrecy(*it)) {
                     createEvent(ts, *it, dt);
                 }
@@ -299,27 +304,24 @@ void HtmlExport::createEventList(QTextStream *ts)
     *ts << "</table>" << endl;
 }
 
-void HtmlExport::createEvent(QTextStream *ts,
-                             const Event::Ptr &event,
-                             QDate date,
-                             bool withDescription)
+void HtmlExport::createEvent(QTextStream *ts, const Event::Ptr &event, QDate date, bool withDescription)
 {
     qCDebug(KCALUTILS_LOG) << event->summary();
     *ts << "  <tr>" << endl;
 
     if (!event->allDay()) {
-        if (event->isMultiDay(d->mCalendar->timeSpec()) && (event->dtStart().date() != date)) {
+        if (event->isMultiDay(d->mCalendar->timeZone()) && (event->dtStart().date() != date)) {
             *ts << "    <td>&nbsp;</td>" << endl;
         } else {
             *ts << "    <td valign=\"top\">"
-                << Stringify::formatTime(event->dtStart(), true, d->mCalendar->timeSpec())
+                << IncidenceFormatter::timeToString(event->dtStart().toLocalTime().time(), true)
                 << "</td>" << endl;
         }
-        if (event->isMultiDay(d->mCalendar->timeSpec()) && (event->dtEnd().date() != date)) {
+        if (event->isMultiDay(d->mCalendar->timeZone()) && (event->dtEnd().date() != date)) {
             *ts << "    <td>&nbsp;</td>" << endl;
         } else {
             *ts << "    <td valign=\"top\">"
-                << Stringify::formatTime(event->dtEnd(), true, d->mCalendar->timeSpec())
+                << IncidenceFormatter::timeToString(event->dtEnd().toLocalTime().time(), true)
                 << "</td>" << endl;
         }
     } else {
@@ -380,14 +382,15 @@ void HtmlExport::createTodoList(QTextStream *ts)
     // replaced by a real sorting algorithm.
     Todo::List todoList;
     Todo::List::ConstIterator it;
+    const Todo::List::ConstIterator end(rawTodoList.constEnd());
     for (int i = 1; i <= 9; ++i) {
-        for (it = rawTodoList.constBegin(); it != rawTodoList.constEnd(); ++it) {
+        for (it = rawTodoList.constBegin(); it != end; ++it) {
             if ((*it)->priority() == i && checkSecrecy(*it)) {
                 todoList.append(*it);
             }
         }
     }
-    for (it = rawTodoList.constBegin(); it != rawTodoList.constEnd(); ++it) {
+    for (it = rawTodoList.constBegin(); it != end; ++it) {
         if ((*it)->priority() == 0 && checkSecrecy(*it)) {
             todoList.append(*it);
         }
@@ -427,7 +430,7 @@ void HtmlExport::createTodoList(QTextStream *ts)
 
     // Create sub-level lists
     for (it = todoList.constBegin(); it != todoList.constEnd(); ++it) {
-        Incidence::List relations =  d->mCalendar->relations((*it)->uid());
+        Incidence::List relations = d->mCalendar->relations((*it)->uid());
 
         if (relations.count()) {
             // Generate sub-to-do list
@@ -436,7 +439,7 @@ void HtmlExport::createTodoList(QTextStream *ts)
             *ts << "\"" << QString::number(columns) << "\"";
             *ts << "><a name=\"sub" << (*it)->uid() << "\"></a>"
                 << i18nc("@title:column sub-to-dos of the parent to-do",
-                         "Sub-To-dos of: ") << "<a href=\"#"
+                     "Sub-To-dos of: ") << "<a href=\"#"
                 << (*it)->uid() << "\"><b>" << cleanChars((*it)->summary())
                 << "</b></a></td>" << endl;
             *ts << "  </tr>" << endl;
@@ -494,7 +497,7 @@ void HtmlExport::createTodo(QTextStream *ts, const Todo::Ptr &todo)
     if (relations.count()) {
         *ts << "    <div align=\"right\"><a href=\"#sub" << todo->uid()
             << "\">" << i18nc("@title:column sub-to-dos of the parent to-do",
-                              "Sub-To-dos") << "</a></div>" << endl;
+                          "Sub-To-dos") << "</a></div>" << endl;
     }
     *ts << "  </td>" << endl;
 
@@ -522,7 +525,7 @@ void HtmlExport::createTodo(QTextStream *ts, const Todo::Ptr &todo)
         }
         *ts << ">" << endl;
         if (todo->hasDueDate()) {
-            *ts << "    " << Stringify::formatDate(todo->dtDue(true)) << endl;
+            *ts << "    " << IncidenceFormatter::dateToString(todo->dtDue(true).toLocalTime().date()) << endl;
         } else {
             *ts << "    &nbsp;" << endl;
         }
@@ -590,15 +593,14 @@ bool HtmlExport::checkSecrecy(const Incidence::Ptr &incidence)
     if (secrecy == Incidence::SecrecyPrivate && !d->mSettings->excludePrivate()) {
         return true;
     }
-    if (secrecy == Incidence::SecrecyConfidential &&
-            !d->mSettings->excludeConfidential()) {
+    if (secrecy == Incidence::SecrecyConfidential
+        && !d->mSettings->excludeConfidential()) {
         return true;
     }
     return false;
 }
 
-void HtmlExport::formatLocation(QTextStream *ts,
-                                const Incidence::Ptr &incidence)
+void HtmlExport::formatLocation(QTextStream *ts, const Incidence::Ptr &incidence)
 {
     if (!incidence->location().isEmpty()) {
         *ts << "    " << cleanChars(incidence->location()) << endl;
@@ -607,8 +609,7 @@ void HtmlExport::formatLocation(QTextStream *ts,
     }
 }
 
-void HtmlExport::formatCategories(QTextStream *ts,
-                                  const Incidence::Ptr &incidence)
+void HtmlExport::formatCategories(QTextStream *ts, const Incidence::Ptr &incidence)
 {
     if (!incidence->categoriesStr().isEmpty()) {
         *ts << "    " << cleanChars(incidence->categoriesStr()) << endl;
@@ -617,8 +618,7 @@ void HtmlExport::formatCategories(QTextStream *ts,
     }
 }
 
-void HtmlExport::formatAttendees(QTextStream *ts,
-                                 const Incidence::Ptr &incidence)
+void HtmlExport::formatAttendees(QTextStream *ts, const Incidence::Ptr &incidence)
 {
     Attendee::List attendees = incidence->attendees();
     if (attendees.count()) {
@@ -626,7 +626,8 @@ void HtmlExport::formatAttendees(QTextStream *ts,
         *ts << incidence->organizer()->fullName();
         *ts << "</em><br />";
         Attendee::List::ConstIterator it;
-        for (it = attendees.constBegin(); it != attendees.constEnd(); ++it) {
+        const Attendee::List::ConstIterator end(attendees.constEnd());
+        for (it = attendees.constBegin(); it != end; ++it) {
             Attendee::Ptr a(*it);
             if (!a->email().isEmpty()) {
                 *ts << "<a href=\"mailto:" << a->email();
@@ -643,16 +644,15 @@ void HtmlExport::formatAttendees(QTextStream *ts,
 
 QString HtmlExport::breakString(const QString &text)
 {
-    int number = text.count(QStringLiteral("\n"));
+    int number = text.count(QLatin1Char('\n'));
     if (number <= 0) {
         return text;
     } else {
         QString out;
         QString tmpText = text;
-        int pos = 0;
         QString tmp;
         for (int i = 0; i <= number; ++i) {
-            pos = tmpText.indexOf(QLatin1String("\n"));
+            int pos = tmpText.indexOf(QLatin1Char('\n'));
             tmp = tmpText.left(pos);
             tmpText = tmpText.right(tmpText.length() - pos - 1);
             out += tmp + QLatin1String("<br />");
